##  Updating the Dashboard
Admin users can update the dashboard to the latest version, making the new version available to all workspace users. You can also delete the previous dashboard version and make the new dashboard the default for workspace users. To learn more about managing dashboards, see [Dashboard Templates](https://help.sap.com/docs/leanix/ea/dashboards-settings?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759a5e37a441014acd0dfe4da61c1c5__dashboard_templates).
Follow these steps:
  1. Go to the Dashboards section in the administration area.
  2. Locate the Templates settings group, click Add template for the Enterprise Architect Onboarding Dashboard (v3) template, then confirm your action.
  3. Make the onboarding dashboard v3 the default for workspace users. To do this, select it in the Default Dashboard list.
  4. Delete the onboarding dashboard v2. To do this, navigate to Dashboard Details from the dashboard, then choose Delete.
